<?php

namespace App\Repository;

use App\Controller\NumberOfSoldByParams;
use App\Entity\ValeursFonciere;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method ValeursFonciere|null find($id, $lockMode = null, $lockVersion = null)
 * @method ValeursFonciere|null findOneBy(array $criteria, array $orderBy = null)
 * @method ValeursFonciere[]    findAll()
 * @method ValeursFonciere[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class ValeursFonciereRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, ValeursFonciere::class);
    }

    public function getMeanPriceForSquaredMeter(){
        $query = "  SELECT
                        TO_CHAR(valeurs_fonciere.date_mutation, 'YYYY') AS year,
                        TO_CHAR(valeurs_fonciere.date_mutation, 'MM') AS month,
                        AVG(valeurs_fonciere.valeur_fonciere / valeurs_fonciere.surface_reelle_bati) AS mean_metre_price
                    FROM
                        App:ValeursFonciere AS valeurs_fonciere
                    WHERE
                        valeurs_fonciere.surface_reelle_bati > 0
                        AND
                        valeurs_fonciere.valeur_fonciere > 0
                        AND
                        lower(valeurs_fonciere.nature_mutation) = 'vente'
                    GROUP BY 
                        year,
                        month
                    ORDER BY
                        year,
                        month";
        return $this->getEntityManager()->createQuery($query)->getResult();
    }

    public function getNumberOfSoldItemsByParameters($interval, $start_date, $end_date){
        $selection = "TO_CHAR(valeurs_fonciere.date_mutation, 'YYYY') AS year";
        $groupByAndOrder = "year";
        if($interval == NumberOfSoldByParams::$INTERVAL_DAY){
            $selection .= ",
                TO_CHAR(valeurs_fonciere.date_mutation, 'MM') AS month,
                TO_CHAR(valeurs_fonciere.date_mutation, 'DD') AS day
            ";
            $groupByAndOrder .= ",
                month,
                day
            ";
        }elseif ($interval == NumberOfSoldByParams::$INTERVAL_MONTH){
            $selection .= ",
                TO_CHAR(valeurs_fonciere.date_mutation, 'MM') AS month
            ";
            $groupByAndOrder .= ",
                month
            ";
        }
        $query = "  SELECT
                        {$selection},
                        COUNT(valeurs_fonciere.date_mutation) AS number_of_sold
                    FROM
                        App:ValeursFonciere AS valeurs_fonciere
                    WHERE
                        lower(valeurs_fonciere.nature_mutation) = 'vente'
                        AND
                        valeurs_fonciere.date_mutation >= TO_DATE('{$start_date}', 'DD-MM-YYYY')
                        AND
                        valeurs_fonciere.date_mutation <= TO_DATE('{$end_date}', 'DD-MM-YYYY')
                    GROUP BY
                        {$groupByAndOrder}
                    ORDER BY
                        {$groupByAndOrder}";
        return $this->getEntityManager()->createQuery($query)->getResult();
    }

    public function getNumberOfItemsSoldGroupedByDepartement(){
        $query = "  SELECT
                        valeurs_fonciere.code_departement AS code_departement,
                        COUNT(valeurs_fonciere.code_departement) AS count_by_departement
                    FROM
                        App:ValeursFonciere AS valeurs_fonciere
                    WHERE
                        valeurs_fonciere.code_departement > 0
                        AND
                        lower(valeurs_fonciere.nature_mutation) = 'vente'
                    GROUP BY
                        valeurs_fonciere.code_departement";
        return $this->getEntityManager()->createQuery($query)->getResult();
    }
}
