import React, { Component } from 'react'
import GraphsHeader from './GraphsHeader'
import './styles.css';
import * as d3 from "d3";

export class GraphsMeanPriceForSquaredMeter extends Component {

  constructor(props) {
    super(props);
    this.state = {
      isLoading: false,
      error: null,
      data: []
    }
    this.createBubbleChart = this.createBubbleChart.bind(this);
    this.container = React.createRef();
    this.svg = React.createRef();
  }

  render() {
    return (
      <div>
          <GraphsHeader />
          <div ref={this.container} className="container pt-5">
            <h1 class="text-center">
              Mean squared meter price
            </h1>
            {this.getComponentBody()}
          </div>
      </div>
    )
  }

  getComponentBody(){
    const {isLoading, error, data } = this.state;
    if(error){
      return (<div className="alert alert-danger">{error.error}</div>);
    }
    if(isLoading){
      return (<div className="alert alert-success">Loading...</div>);
    }
    console.log(data);
    return this.getGraph();
  }

  getGraph(){
    return (<svg ref={this.svg} class="graph1"></svg>);
  }

  createBubbleChart(){
    const margin = {
      left: 50,
      bottom: 20
    };
    let data = this.state.data;
    let maxHeight = 0;
    data = data.map((item, index) => {
      if(item.mean_metre_price > maxHeight){
        maxHeight = item.mean_metre_price;
      }
      item.order = index;
      return item;
    });
    var width = this.container.current.clientWidth - 30,
        height = 600;
    var x = d3.scaleLinear().rangeRound([margin.left, width]);
    var y = d3.scaleLinear().rangeRound([height, margin.bottom]);
    var x_year = d3.scaleLinear().rangeRound([margin.left, width]);
    // Append SVG
    var svg = d3.select(this.svg.current).attr('width', width).attr("height", height).attr("viewBox", "0 0 " + width + " " + height);
    var drawAxis = function(yValueCallback, color) {
        x.domain([0, data.length + 5]);
        y.domain([0, maxHeight]);
        x_year.domain([2014.5, 2019.5])
        svg.append('path')
            .datum(data)
            .attr("fill", "none")
            .attr("stroke", color)
            .attr("stroke-linejoin", "round")
            .attr("stroke-linecap", "round")
            .attr("stroke-width", 5)
            .attr("d", d3.line().x(function(d) { return x(d.order); }).y(yValueCallback))
            .attr("transform", `translate(0,-${margin.bottom})`)
            .attr("class", "time-series");
          var x_axis = d3.axisBottom()
            .scale(x)
            .tickFormat("")
            .tickValues([11,23,35,47]);
          var y_axis = d3.axisLeft()
            .scale(y);
          var x_year_axis = d3.axisBottom()
            .scale(x_year)
            .tickFormat(d3.format("d"))
            .tickValues([2015, 2016, 2017, 2018, 2019]);
          svg.append("g")
            .attr("transform", `translate(0,${height - margin.bottom})`)
            .call(x_axis);
          svg.append("g")
          .attr("transform", `translate(${margin.left},-${margin.bottom})`)
            .call(y_axis);
          svg.append("g")
            .attr("transform", `translate(0,${height - margin.bottom})`)
            .call(x_year_axis);
    };
    drawAxis(function(d) { return y(d.mean_metre_price); }, "blue");
  }


  componentDidMount() {
    this.setState({ isLoading: true })
    fetch(`https://${document.domain}:8443/mean-price-for-squared-meter`)
      .then(response => {
        if (response.ok) {
          const data = response.json()
          return data;
        } else {
          throw new Error('Something went wrong ...');
        }
      })
      .then(data => {
        this.setState({data: data, isLoading: false });
      })
      .catch(error => this.setState({ error: error, isLoading: false }));
  }

  componentDidUpdate(){
    if(this.state.isLoading === false || this.error == null){
      this.createBubbleChart();
    }
  }
}

export default GraphsMeanPriceForSquaredMeter
